aboutsummaryrefslogtreecommitdiffstats
path: root/app/scripts/controllers/provider-approval.js
diff options
context:
space:
mode:
Diffstat (limited to 'app/scripts/controllers/provider-approval.js')
-rw-r--r--app/scripts/controllers/provider-approval.js6
1 files changed, 3 insertions, 3 deletions
diff --git a/app/scripts/controllers/provider-approval.js b/app/scripts/controllers/provider-approval.js
index 893ddec8..6c83acb7 100644
--- a/app/scripts/controllers/provider-approval.js
+++ b/app/scripts/controllers/provider-approval.js
@@ -77,7 +77,7 @@ class ProviderApprovalController {
}
/**
* Called by a tab to determine if MetaMask is currently locked or unlocked
*/
_handleIsUnlocked () {
const isUnlocked = this.keyringController.memStore.getState().isUnlocked
@@ -149,11 +149,11 @@ class ProviderApprovalController {
}
/**
* Tells all tabs that MetaMask is now locked. This is primarily used to set
* internal flags in the contentscript and inpage script.
*/
setLocked () {
- this.platform.sendMessage({ action: 'metamask-set-locked' })
+ this.platform.sendMessage({ action: 'dekusan-set-locked' })
}
}
@@ -77,7 +77,7 @@ class ProviderApprovalController {
}
/**
- * Called by a tab to determine if MetaMask is currently locked or unlocked
+ * Called by a tab to determine if DekuSan is currently locked or unlocked
*/
_handleIsUnlocked () {
@@ -149,11 +149,11 @@ class ProviderApprovalController {
}
/**
- * Tells all tabs that MetaMask is now locked. This is primarily used to set
+ * Tells all tabs that DekuSan is now locked. This is primarily used to set
* internal flags in the contentscript and inpage script.
*/